"""Version information for KuzuMemory."""

__version__ = "1.1.13"
__version_info__ = tuple(int(i) for i in __version__.split("."))

# Database schema version for migration support
DB_SCHEMA_VERSION = "1.0"
